/* First steps in econometrics */
/* Chapter 11 */
/* Ryuichi Tanaka (University of Tokyo) */

clear
use final5.dta 

* clearning data
replace avgverb= avgverb-100 if avgverb>100
replace avgmath= avgmath-100 if avgmath>100
replace avgverb=. if verbsize==0
replace avgmath=. if mathsize==0
keep if 1<classize & classize<45 & c_size>5
generate c_size2= (c_size^2)/100

* predicted class size
generate func1= c_size/(int((c_size-1)/40)+1)

* generate discontinuity sample (+-5) 
generate disc= (c_size>=36 & c_size<=45) | (c_size>=76 & c_size<=85) | (c_size>=116 & c_size<=125)

* generate trendj
generate trend= c_size if c_size>=0 & c_size<=40
replace trend= 20+(c_size/2) if c_size>=41 & c_size<=80
replace trend= (100/3)+(c_size/3) if c_size>=81 & c_size<=120
replace trend= (130/3)+(c_size/4) if c_size>=121 & c_size<=160

keep avgverb avgmath classize tipuach trend func1 disc schlcode c_size c_size2

label variable classize "class size"
label variable c_size "enrollment"
label variable c_size2 "c_size^2"
label variable tipuach "share of students from disadvantaged household"
label variable func1 "predicted class size"
label variable trend "trend"
label variable disc "=1 for discontinuity sample"

* Table 2
* verbal
summarize avgverb avgmath
regress avgverb classize, cluster(schlcode)
regress avgverb classize tipuach, cluster(schlcode)
regress avgverb classize tipuach c_size, cluster(schlcode)

* mathematics
regress avgmath classize, cluster(schlcode)
regress avgmath classize tipuach, cluster(schlcode)
regress avgmath classize tipuach c_size, cluster(schlcode)

* Table 4
* verbal

ivregress 2sls avgverb (classize=func1) tipuach, cluster(schlcode)
ivregress 2sls avgverb (classize=func1) tipuach c_size, cluster(schlcode)
ivregress 2sls avgverb (classize=func1) tipuach c_size c_size2, cluster(schlcode)
ivregress 2sls avgverb (classize=func1) trend, cluster(schlcode)
ivregress 2sls avgverb (classize=func1) tipuach if disc==1, cluster(schlcode)
ivregress 2sls avgverb (classize=func1) tipuach c_size if disc==1, cluster(schlcode)


* mathematics
ivregress 2sls avgmath (classize=func1) tipuach, cluster(schlcode)
ivregress 2sls avgmath (classize=func1) tipuach c_size, cluster(schlcode)
ivregress 2sls avgmath (classize=func1) tipuach c_size c_size2, cluster(schlcode)
ivregress 2sls avgmath (classize=func1) trend, cluster(schlcode)
ivregress 2sls avgmath (classize=func1) tipuach if disc==1, cluster(schlcode)
ivregress 2sls avgmath (classize=func1) tipuach c_size if disc==1, cluster(schlcode)
